yakumo.neutron.v2.vpn.ipsec_site_connection

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_site_connection |
[hide private]
[frames] | no frames]

# Module ipsec_site_connection

source code

Resource class and its manager for VPN IPSec site connections in Networking V2 API

Classes | [hide private]
| Resource Resource class for VPN IPSec site connections in Networking V2 API
| Manager Manager class for VPN IPSec site connections in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.vpn``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('peer_address', 'peer_address', map
      per.Noop), ('peer_id', 'peer_id', mapper.Noop), ('local_ep_group_id',
      'local_ep_group_id', mapper.Noop), ('peer_ep_group_id', 'peer_ep_group
      _id', mapper.Noop), ('peer_cidrs', 'peer_cidrs', mapper.Noop), ('route
      _mode', 'route_mode', mapper.Noop), ('mtu', 'mtu', mapper.Noop), ('aut
      h_mode', 'auth_mode', mapper.Noop), ('psk', 'psk', mapper.Noop), ('ini
      tiator', 'initiator', mapper.Noop), ('ikepolicy', 'ikepolicy_id', mapp
      ...